Collapsible Dock Widget (dock)

# Orange Canvas Core 0.0.8 documentation

## Collapsible Dock Widget (dock)

# Collapsible Dock Widget (`dock`)

## Collapsible Dock Widget

A dock widget that can be a collapsed/expanded.

class `orangecanvas.gui.dock.` `CollapsibleDockWidget`(*args, **kwargs)

  Bases: `PyQt5.QtWidgets.QDockWidget`

  This `QDockWidget` subclass overrides the close header button to instead collapse to a smaller size. The contents contents to show when in each state can be set using the `setExpandedWidget` and `setCollapsedWidget`.

  Note

  Do not use the base class `QDockWidget.setWidget` method to set the docks contents. Use set[Expanded|Collapsed]Widget instead.

  `expandedChanged`

    Emitted when the dock widget’s expanded state changes.

  `setExpanded`(state)

    Set the widgets expanded state.

  `expanded`()

    Is the dock widget in expanded state. If True the `expandedWidget` will be shown, and `collapsedWidget` otherwise.

  `expanded_`

    Is the dock widget in expanded state. If True the `expandedWidget` will be shown, and `collapsedWidget` otherwise.

  `setExpandedWidget`(widget)

    Set the widget with contents to show while expanded.

  `expandedWidget`()

    Return the widget previously set with `setExpandedWidget`, or `None` if no widget has been set.

  `setCollapsedWidget`(widget)

    Set the widget with contents to show while collapsed.

  `collapsedWidget`()

    Return the widget previously set with `setCollapsedWidget`, or `None` if no widget has been set.

  `setAnimationEnabled`(animationEnabled)

    Enable/disable the transition animation.

  `animationEnabled`()

    Is transition animation enabled.

  `currentWidget`()

    Return the current shown widget depending on the expanded state.

  `expand`()

    Expand the dock (same as `setExpanded(True)`)

  `collapse`()

    Collapse the dock (same as `setExpanded(False)`)